@@ -5,6 +5,7 @@ import json
 import re
 import requests
 from requests import structures
+import sys
 try:
     import urlparse
 except ImportError:
@@ -27,7 +28,10 @@ def response(status_code=200, content='', headers=None, reason=None, elapsed=0,
     res = requests.Response()
     res.status_code = status_code
     if isinstance(content, dict):
-        content = json.dumps(content)
+        if sys.version_info[0] == 3:
+            content = bytes(json.dumps(content), 'utf-8')
+        else:
+            content = json.dumps(content)
     res._content = content
     res.headers = structures.CaseInsensitiveDict(headers or {})
     res.reason = reason
